/* Copyright 2018 The Tor Project
 * See LICENSE for licensing information */

package org.torproject.descriptor;

/** Enum for web server access log methods. */
public enum Method {
    GET, HEAD, POST
}
